from typing import Any, Dict, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient
from ...models.base_error import BaseError
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    upload_length: Union[Unset, int] = UNSET,
    tus_resumable: str,
    upload_metadata: str,
    content_length: int,
    content_type: Union[Unset, str] = UNSET,
    upload_concat: Union[Unset, str] = UNSET,
    upload_defer_length: Union[Unset, int] = UNSET,
    upload_checksum: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/uploads/".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    if not isinstance(upload_length, Unset):
        headers["upload-length"] = str(upload_length)

    headers["tus-resumable"] = tus_resumable

    headers["upload-metadata"] = upload_metadata

    headers["content-length"] = str(content_length)

    if not isinstance(content_type, Unset):
        headers["content-type"] = content_type

    if not isinstance(upload_concat, Unset):
        headers["upload-concat"] = upload_concat

    if not isinstance(upload_defer_length, Unset):
        headers["upload-defer-length"] = str(upload_defer_length)

    if not isinstance(upload_checksum, Unset):
        headers["upload-checksum"] = upload_checksum

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[Any, BaseError, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = cast(Any, response.json())
        return response_200
    if response.status_code == 400:
        response_400 = BaseError.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = BaseError.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = BaseError.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = BaseError.from_dict(response.json())

        return response_404
    if response.status_code == 409:
        response_409 = BaseError.from_dict(response.json())

        return response_409
    if response.status_code == 410:
        response_410 = BaseError.from_dict(response.json())

        return response_410
    if response.status_code == 413:
        response_413 = BaseError.from_dict(response.json())

        return response_413
    if response.status_code == 500:
        response_500 = BaseError.from_dict(response.json())

        return response_500
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[Any, BaseError, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    upload_length: Union[Unset, int] = UNSET,
    tus_resumable: str,
    upload_metadata: str,
    content_length: int,
    content_type: Union[Unset, str] = UNSET,
    upload_concat: Union[Unset, str] = UNSET,
    upload_defer_length: Union[Unset, int] = UNSET,
    upload_checksum: Union[Unset, str] = UNSET,
) -> Response[Union[Any, BaseError, HTTPValidationError]]:
    """Start Upload

    Args:
        upload_length (Union[Unset, int]):
        tus_resumable (str):
        upload_metadata (str):
        content_length (int):
        content_type (Union[Unset, str]):
        upload_concat (Union[Unset, str]):
        upload_defer_length (Union[Unset, int]):
        upload_checksum (Union[Unset, str]):

    Returns:
        Response[Union[Any, BaseError, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        client=client,
        upload_length=upload_length,
        tus_resumable=tus_resumable,
        upload_metadata=upload_metadata,
        content_length=content_length,
        content_type=content_type,
        upload_concat=upload_concat,
        upload_defer_length=upload_defer_length,
        upload_checksum=upload_checksum,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    upload_length: Union[Unset, int] = UNSET,
    tus_resumable: str,
    upload_metadata: str,
    content_length: int,
    content_type: Union[Unset, str] = UNSET,
    upload_concat: Union[Unset, str] = UNSET,
    upload_defer_length: Union[Unset, int] = UNSET,
    upload_checksum: Union[Unset, str] = UNSET,
) -> Optional[Union[Any, BaseError, HTTPValidationError]]:
    """Start Upload

    Args:
        upload_length (Union[Unset, int]):
        tus_resumable (str):
        upload_metadata (str):
        content_length (int):
        content_type (Union[Unset, str]):
        upload_concat (Union[Unset, str]):
        upload_defer_length (Union[Unset, int]):
        upload_checksum (Union[Unset, str]):

    Returns:
        Response[Union[Any, BaseError, HTTPValidationError]]
    """

    return sync_detailed(
        client=client,
        upload_length=upload_length,
        tus_resumable=tus_resumable,
        upload_metadata=upload_metadata,
        content_length=content_length,
        content_type=content_type,
        upload_concat=upload_concat,
        upload_defer_length=upload_defer_length,
        upload_checksum=upload_checksum,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    upload_length: Union[Unset, int] = UNSET,
    tus_resumable: str,
    upload_metadata: str,
    content_length: int,
    content_type: Union[Unset, str] = UNSET,
    upload_concat: Union[Unset, str] = UNSET,
    upload_defer_length: Union[Unset, int] = UNSET,
    upload_checksum: Union[Unset, str] = UNSET,
) -> Response[Union[Any, BaseError, HTTPValidationError]]:
    """Start Upload

    Args:
        upload_length (Union[Unset, int]):
        tus_resumable (str):
        upload_metadata (str):
        content_length (int):
        content_type (Union[Unset, str]):
        upload_concat (Union[Unset, str]):
        upload_defer_length (Union[Unset, int]):
        upload_checksum (Union[Unset, str]):

    Returns:
        Response[Union[Any, BaseError, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        client=client,
        upload_length=upload_length,
        tus_resumable=tus_resumable,
        upload_metadata=upload_metadata,
        content_length=content_length,
        content_type=content_type,
        upload_concat=upload_concat,
        upload_defer_length=upload_defer_length,
        upload_checksum=upload_checksum,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    upload_length: Union[Unset, int] = UNSET,
    tus_resumable: str,
    upload_metadata: str,
    content_length: int,
    content_type: Union[Unset, str] = UNSET,
    upload_concat: Union[Unset, str] = UNSET,
    upload_defer_length: Union[Unset, int] = UNSET,
    upload_checksum: Union[Unset, str] = UNSET,
) -> Optional[Union[Any, BaseError, HTTPValidationError]]:
    """Start Upload

    Args:
        upload_length (Union[Unset, int]):
        tus_resumable (str):
        upload_metadata (str):
        content_length (int):
        content_type (Union[Unset, str]):
        upload_concat (Union[Unset, str]):
        upload_defer_length (Union[Unset, int]):
        upload_checksum (Union[Unset, str]):

    Returns:
        Response[Union[Any, BaseError, HTTPValidationError]]
    """

    return (
        await asyncio_detailed(
            client=client,
            upload_length=upload_length,
            tus_resumable=tus_resumable,
            upload_metadata=upload_metadata,
            content_length=content_length,
            content_type=content_type,
            upload_concat=upload_concat,
            upload_defer_length=upload_defer_length,
            upload_checksum=upload_checksum,
        )
    ).parsed



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.scope_out import ScopeOut
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserOut")


@attr.s(auto_attribs=True)
class UserOut:
    """
    Attributes:
        username (str):
        firstname (str):
        lastname (str):
        email (str):
        active (Union[Unset, bool]):  Default: True.
        admin (Union[Unset, bool]):
        created (Union[Unset, datetime.datetime]):
        modified (Union[Unset, datetime.datetime]):
        scopes (Union[Unset, List[ScopeOut]]):
    """

    username: str
    firstname: str
    lastname: str
    email: str
    active: Union[Unset, bool] = True
    admin: Union[Unset, bool] = False
    created: Union[Unset, datetime.datetime] = UNSET
    modified: Union[Unset, datetime.datetime] = UNSET
    scopes: Union[Unset, List[ScopeOut]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        username = self.username
        firstname = self.firstname
        lastname = self.lastname
        email = self.email
        active = self.active
        admin = self.admin
        created: Union[Unset, str] = UNSET
        if not isinstance(self.created, Unset):
            created = self.created.isoformat()

        modified: Union[Unset, str] = UNSET
        if not isinstance(self.modified, Unset):
            modified = self.modified.isoformat()

        scopes: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.scopes, Unset):
            scopes = []
            for scopes_item_data in self.scopes:
                scopes_item = scopes_item_data.to_dict()

                scopes.append(scopes_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "username": username,
                "firstname": firstname,
                "lastname": lastname,
                "email": email,
            }
        )
        if active is not UNSET:
            field_dict["active"] = active
        if admin is not UNSET:
            field_dict["admin"] = admin
        if created is not UNSET:
            field_dict["created"] = created
        if modified is not UNSET:
            field_dict["modified"] = modified
        if scopes is not UNSET:
            field_dict["scopes"] = scopes

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        username = d.pop("username")

        firstname = d.pop("firstname")

        lastname = d.pop("lastname")

        email = d.pop("email")

        active = d.pop("active", UNSET)

        admin = d.pop("admin", UNSET)

        _created = d.pop("created", UNSET)
        created: Union[Unset, datetime.datetime]
        if isinstance(_created, Unset):
            created = UNSET
        else:
            created = isoparse(_created)

        _modified = d.pop("modified", UNSET)
        modified: Union[Unset, datetime.datetime]
        if isinstance(_modified, Unset):
            modified = UNSET
        else:
            modified = isoparse(_modified)

        scopes = []
        _scopes = d.pop("scopes", UNSET)
        for scopes_item_data in _scopes or []:
            scopes_item = ScopeOut.from_dict(scopes_item_data)

            scopes.append(scopes_item)

        user_out = cls(
            username=username,
            firstname=firstname,
            lastname=lastname,
            email=email,
            active=active,
            admin=admin,
            created=created,
            modified=modified,
            scopes=scopes,
        )

        user_out.additional_properties = d
        return user_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="ScopeOut")


@attr.s(auto_attribs=True)
class ScopeOut:
    """
    Attributes:
        name (str):
        description (str):
        restricted (Union[Unset, bool]):
        archived (Union[Unset, bool]):
        created (Union[Unset, datetime.datetime]):
        modified (Union[Unset, datetime.datetime]):
    """

    name: str
    description: str
    restricted: Union[Unset, bool] = False
    archived: Union[Unset, bool] = False
    created: Union[Unset, datetime.datetime] = UNSET
    modified: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        description = self.description
        restricted = self.restricted
        archived = self.archived
        created: Union[Unset, str] = UNSET
        if not isinstance(self.created, Unset):
            created = self.created.isoformat()

        modified: Union[Unset, str] = UNSET
        if not isinstance(self.modified, Unset):
            modified = self.modified.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "description": description,
            }
        )
        if restricted is not UNSET:
            field_dict["restricted"] = restricted
        if archived is not UNSET:
            field_dict["archived"] = archived
        if created is not UNSET:
            field_dict["created"] = created
        if modified is not UNSET:
            field_dict["modified"] = modified

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        description = d.pop("description")

        restricted = d.pop("restricted", UNSET)

        archived = d.pop("archived", UNSET)

        _created = d.pop("created", UNSET)
        created: Union[Unset, datetime.datetime]
        if isinstance(_created, Unset):
            created = UNSET
        else:
            created = isoparse(_created)

        _modified = d.pop("modified", UNSET)
        modified: Union[Unset, datetime.datetime]
        if isinstance(_modified, Unset):
            modified = UNSET
        else:
            modified = isoparse(_modified)

        scope_out = cls(
            name=name,
            description=description,
            restricted=restricted,
            archived=archived,
            created=created,
            modified=modified,
        )

        scope_out.additional_properties = d
        return scope_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

T = TypeVar("T", bound="DatasetInMeta")


@attr.s(auto_attribs=True)
class DatasetInMeta:
    """ """

    additional_properties: Dict[str, Union[List[str], str]] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():

            if isinstance(prop, list):
                field_dict[prop_name] = prop

            else:
                field_dict[prop_name] = prop

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        dataset_in_meta = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():

            def _parse_additional_property(data: object) -> Union[List[str], str]:
                try:
                    if not isinstance(data, list):
                        raise TypeError()
                    additional_property_type_0 = cast(List[str], data)

                    return additional_property_type_0
                except:  # noqa: E722
                    pass
                return cast(Union[List[str], str], data)

            additional_property = _parse_additional_property(prop_dict)

            additional_properties[prop_name] = additional_property

        dataset_in_meta.additional_properties = additional_properties
        return dataset_in_meta

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Union[List[str], str]:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Union[List[str], str]) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.file_type import FileType
from ..types import UNSET, Unset

T = TypeVar("T", bound="FileDatasetIn")


@attr.s(auto_attribs=True)
class FileDatasetIn:
    """
    Attributes:
        name (str):
        uid (str):
        creator (Union[Unset, str]):
        etag (Union[Unset, str]):
        size (Union[Unset, int]):
        mimetype (Union[Unset, str]):  Default: 'application/octet-stream'.
        altlocation (Union[Unset, str]):
        rating (Union[Unset, int]):
        immutable (Union[Unset, bool]):  Default: True.
        filetype (Union[Unset, FileType]): An enumeration.
        dataset_uid (Union[Unset, str]):
        scope (Union[Unset, str]):
    """

    name: str
    uid: str
    creator: Union[Unset, str] = UNSET
    etag: Union[Unset, str] = UNSET
    size: Union[Unset, int] = UNSET
    mimetype: Union[Unset, str] = "application/octet-stream"
    altlocation: Union[Unset, str] = UNSET
    rating: Union[Unset, int] = 0
    immutable: Union[Unset, bool] = True
    filetype: Union[Unset, FileType] = UNSET
    dataset_uid: Union[Unset, str] = UNSET
    scope: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        uid = self.uid
        creator = self.creator
        etag = self.etag
        size = self.size
        mimetype = self.mimetype
        altlocation = self.altlocation
        rating = self.rating
        immutable = self.immutable
        filetype: Union[Unset, str] = UNSET
        if not isinstance(self.filetype, Unset):
            #filetype = self.filetype.value
            filetype = self.filetype

        dataset_uid = self.dataset_uid
        scope = self.scope

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "uid": uid,
            }
        )
        if creator is not UNSET:
            field_dict["creator"] = creator
        if etag is not UNSET:
            field_dict["etag"] = etag
        if size is not UNSET:
            field_dict["size"] = size
        if mimetype is not UNSET:
            field_dict["mimetype"] = mimetype
        if altlocation is not UNSET:
            field_dict["altlocation"] = altlocation
        if rating is not UNSET:
            field_dict["rating"] = rating
        if immutable is not UNSET:
            field_dict["immutable"] = immutable
        if filetype is not UNSET:
            field_dict["filetype"] = filetype
        if dataset_uid is not UNSET:
            field_dict["dataset_uid"] = dataset_uid
        if scope is not UNSET:
            field_dict["scope"] = scope

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        uid = d.pop("uid")

        creator = d.pop("creator", UNSET)

        etag = d.pop("etag", UNSET)

        size = d.pop("size", UNSET)

        mimetype = d.pop("mimetype", UNSET)

        altlocation = d.pop("altlocation", UNSET)

        rating = d.pop("rating", UNSET)

        immutable = d.pop("immutable", UNSET)

        _filetype = d.pop("filetype", UNSET)
        filetype: Union[Unset, FileType]
        if isinstance(_filetype, Unset):
            filetype = UNSET
        else:
            filetype = FileType(_filetype)

        dataset_uid = d.pop("dataset_uid", UNSET)

        scope = d.pop("scope", UNSET)

        file_dataset_in = cls(
            name=name,
            uid=uid,
            creator=creator,
            etag=etag,
            size=size,
            mimetype=mimetype,
            altlocation=altlocation,
            rating=rating,
            immutable=immutable,
            filetype=filetype,
            dataset_uid=dataset_uid,
            scope=scope,
        )

        file_dataset_in.additional_properties = d
        return file_dataset_in

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.file_type import FileType
from ..types import UNSET, Unset

T = TypeVar("T", bound="FileUpdate")


@attr.s(auto_attribs=True)
class FileUpdate:
    """
    Attributes:
        name (Union[Unset, str]):
        mimetype (Union[Unset, str]):
        filetype (Union[Unset, FileType]): An enumeration.
        rating (Union[Unset, int]):
    """

    name: Union[Unset, str] = UNSET
    mimetype: Union[Unset, str] = UNSET
    filetype: Union[Unset, FileType] = UNSET
    rating: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        mimetype = self.mimetype
        filetype: Union[Unset, str] = UNSET
        if not isinstance(self.filetype, Unset):
            filetype = self.filetype.value

        rating = self.rating

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if mimetype is not UNSET:
            field_dict["mimetype"] = mimetype
        if filetype is not UNSET:
            field_dict["filetype"] = filetype
        if rating is not UNSET:
            field_dict["rating"] = rating

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        mimetype = d.pop("mimetype", UNSET)

        _filetype = d.pop("filetype", UNSET)
        filetype: Union[Unset, FileType]
        if isinstance(_filetype, Unset):
            filetype = UNSET
        else:
            filetype = FileType(_filetype)

        rating = d.pop("rating", UNSET)

        file_update = cls(
            name=name,
            mimetype=mimetype,
            filetype=filetype,
            rating=rating,
        )

        file_update.additional_properties = d
        return file_update

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



""" Contains all the data models used in inputs/outputs """

from .base_error import BaseError
from .body_login_for_access_token import BodyLoginForAccessToken
from .body_refresh_token import BodyRefreshToken
from .collection_dataset_out import CollectionDatasetOut
from .collection_in import CollectionIn
from .collection_out import CollectionOut
from .collection_update import CollectionUpdate
from .dataset_in import DatasetIn
from .dataset_in_meta import DatasetInMeta
from .dataset_meta import DatasetMeta
from .dataset_meta_keys import DatasetMetaKeys
from .dataset_meta_meta import DatasetMetaMeta
from .dataset_out import DatasetOut
from .dataset_out_meta import DatasetOutMeta
from .dataset_update import DatasetUpdate
from .file_dataset_in import FileDatasetIn
from .file_dataset_out import FileDatasetOut
from .file_in import FileIn
from .file_out import FileOut
from .file_status import FileStatus
from .file_type import FileType
from .file_update import FileUpdate
from .http_validation_error import HTTPValidationError
from .scope_in import ScopeIn
from .scope_out import ScopeOut
from .scope_update import ScopeUpdate
from .token import Token
from .user_in import UserIn
from .user_out import UserOut
from .user_update import UserUpdate
from .validation_error import ValidationError



from enum import Enum


class FileStatus(str, Enum):
    UNAVAILABLE = "unavailable"
    PENDING = "pending"
    AVAILABLE = "available"
    SECURED = "secured"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserUpdate")


@attr.s(auto_attribs=True)
class UserUpdate:
    """
    Attributes:
        username (Union[Unset, str]):
        firstname (Union[Unset, str]):
        lastname (Union[Unset, str]):
        email (Union[Unset, str]):
        active (Union[Unset, str]):
        admin (Union[Unset, bool]):
        hashed_password (Union[Unset, str]):
    """

    username: Union[Unset, str] = UNSET
    firstname: Union[Unset, str] = UNSET
    lastname: Union[Unset, str] = UNSET
    email: Union[Unset, str] = UNSET
    active: Union[Unset, str] = UNSET
    admin: Union[Unset, bool] = UNSET
    hashed_password: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        username = self.username
        firstname = self.firstname
        lastname = self.lastname
        email = self.email
        active = self.active
        admin = self.admin
        hashed_password = self.hashed_password

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if username is not UNSET:
            field_dict["username"] = username
        if firstname is not UNSET:
            field_dict["firstname"] = firstname
        if lastname is not UNSET:
            field_dict["lastname"] = lastname
        if email is not UNSET:
            field_dict["email"] = email
        if active is not UNSET:
            field_dict["active"] = active
        if admin is not UNSET:
            field_dict["admin"] = admin
        if hashed_password is not UNSET:
            field_dict["hashed_password"] = hashed_password

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        username = d.pop("username", UNSET)

        firstname = d.pop("firstname", UNSET)

        lastname = d.pop("lastname", UNSET)

        email = d.pop("email", UNSET)

        active = d.pop("active", UNSET)

        admin = d.pop("admin", UNSET)

        hashed_password = d.pop("hashed_password", UNSET)

        user_update = cls(
            username=username,
            firstname=firstname,
            lastname=lastname,
            email=email,
            active=active,
            admin=admin,
            hashed_password=hashed_password,
        )

        user_update.additional_properties = d
        return user_update

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="DatasetUpdate")


@attr.s(auto_attribs=True)
class DatasetUpdate:
    """
    Attributes:
        name (Union[Unset, str]):
        started (Union[Unset, datetime.datetime]):
        duration (Union[Unset, float]):
        description (Union[Unset, str]):
        creator (Union[Unset, str]):
        ranking (Union[Unset, int]):
    """

    name: Union[Unset, str] = UNSET
    started: Union[Unset, datetime.datetime] = UNSET
    duration: Union[Unset, float] = UNSET
    description: Union[Unset, str] = UNSET
    creator: Union[Unset, str] = UNSET
    ranking: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        started: Union[Unset, str] = UNSET
        if not isinstance(self.started, Unset):
            started = self.started.isoformat()

        duration = self.duration
        description = self.description
        creator = self.creator
        ranking = self.ranking

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if started is not UNSET:
            field_dict["started"] = started
        if duration is not UNSET:
            field_dict["duration"] = duration
        if description is not UNSET:
            field_dict["description"] = description
        if creator is not UNSET:
            field_dict["creator"] = creator
        if ranking is not UNSET:
            field_dict["ranking"] = ranking

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name", UNSET)

        _started = d.pop("started", UNSET)
        started: Union[Unset, datetime.datetime]
        if isinstance(_started, Unset):
            started = UNSET
        else:
            started = isoparse(_started)

        duration = d.pop("duration", UNSET)

        description = d.pop("description", UNSET)

        creator = d.pop("creator", UNSET)

        ranking = d.pop("ranking", UNSET)

        dataset_update = cls(
            name=name,
            started=started,
            duration=duration,
            description=description,
            creator=creator,
            ranking=ranking,
        )

        dataset_update.additional_properties = d
        return dataset_update

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.base_error import BaseError
from ...models.dataset_out import DatasetOut
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    scope: str,
    collection: Union[Unset, None, str] = UNSET,
    name: Union[Unset, None, str] = UNSET,
    uid: Union[Unset, None, str] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    until: Union[Unset, None, datetime.datetime] = UNSET,
    sample: Union[Unset, None, str] = UNSET,
    fridge: Union[Unset, None, str] = UNSET,
    setup: Union[Unset, None, str] = UNSET,
    measurement_type: Union[Unset, None, str] = UNSET,
    keywords: Union[Unset, None, List[str]] = UNSET,
    variables_measured: Union[Unset, None, List[str]] = UNSET,
    offset: Union[Unset, None, int] = 0,
    ranking: Union[Unset, None, int] = 0,
    limit: Union[Unset, None, int] = 500,
) -> Dict[str, Any]:
    url = "{}/api/v1/datasets/".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["scope"] = scope

    params["collection"] = collection

    params["name"] = name

    params["uid"] = uid

    json_since: Union[Unset, None, str] = UNSET
    if not isinstance(since, Unset):
        json_since = since.isoformat() if since else None

    params["since"] = json_since

    json_until: Union[Unset, None, str] = UNSET
    if not isinstance(until, Unset):
        json_until = until.isoformat() if until else None

    params["until"] = json_until

    params["sample"] = sample

    params["fridge"] = fridge

    params["setup"] = setup

    params["measurementType"] = measurement_type

    json_keywords: Union[Unset, None, List[str]] = UNSET
    if not isinstance(keywords, Unset):
        if keywords is None:
            json_keywords = None
        else:
            json_keywords = keywords

    params["keywords"] = json_keywords

    json_variables_measured: Union[Unset, None, List[str]] = UNSET
    if not isinstance(variables_measured, Unset):
        if variables_measured is None:
            json_variables_measured = None
        else:
            json_variables_measured = variables_measured

    params["variablesMeasured"] = json_variables_measured

    params["offset"] = offset

    params["ranking"] = ranking

    params["limit"] = limit

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[BaseError, HTTPValidationError, List[DatasetOut]]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = DatasetOut.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if response.status_code == 400:
        response_400 = BaseError.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = BaseError.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = BaseError.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = BaseError.from_dict(response.json())

        return response_404
    if response.status_code == 409:
        response_409 = BaseError.from_dict(response.json())

        return response_409
    if response.status_code == 410:
        response_410 = BaseError.from_dict(response.json())

        return response_410
    if response.status_code == 413:
        response_413 = BaseError.from_dict(response.json())

        return response_413
    if response.status_code == 500:
        response_500 = BaseError.from_dict(response.json())

        return response_500
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[BaseError, HTTPValidationError, List[DatasetOut]]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    scope: str,
    collection: Union[Unset, None, str] = UNSET,
    name: Union[Unset, None, str] = UNSET,
    uid: Union[Unset, None, str] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    until: Union[Unset, None, datetime.datetime] = UNSET,
    sample: Union[Unset, None, str] = UNSET,
    fridge: Union[Unset, None, str] = UNSET,
    setup: Union[Unset, None, str] = UNSET,
    measurement_type: Union[Unset, None, str] = UNSET,
    keywords: Union[Unset, None, List[str]] = UNSET,
    variables_measured: Union[Unset, None, List[str]] = UNSET,
    offset: Union[Unset, None, int] = 0,
    ranking: Union[Unset, None, int] = 0,
    limit: Union[Unset, None, int] = 500,
) -> Response[Union[BaseError, HTTPValidationError, List[DatasetOut]]]:
    """Get Datasets

    Args:
        scope (str):
        collection (Union[Unset, None, str]):
        name (Union[Unset, None, str]):
        uid (Union[Unset, None, str]):
        since (Union[Unset, None, datetime.datetime]):
        until (Union[Unset, None, datetime.datetime]):
        sample (Union[Unset, None, str]):
        fridge (Union[Unset, None, str]):
        setup (Union[Unset, None, str]):
        measurement_type (Union[Unset, None, str]):
        keywords (Union[Unset, None, List[str]]):
        variables_measured (Union[Unset, None, List[str]]):
        offset (Union[Unset, None, int]):
        ranking (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):  Default: 500.

    Returns:
        Response[Union[BaseError, HTTPValidationError, List[DatasetOut]]]
    """

    kwargs = _get_kwargs(
        client=client,
        scope=scope,
        collection=collection,
        name=name,
        uid=uid,
        since=since,
        until=until,
        sample=sample,
        fridge=fridge,
        setup=setup,
        measurement_type=measurement_type,
        keywords=keywords,
        variables_measured=variables_measured,
        offset=offset,
        ranking=ranking,
        limit=limit,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    scope: str,
    collection: Union[Unset, None, str] = UNSET,
    name: Union[Unset, None, str] = UNSET,
    uid: Union[Unset, None, str] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    until: Union[Unset, None, datetime.datetime] = UNSET,
    sample: Union[Unset, None, str] = UNSET,
    fridge: Union[Unset, None, str] = UNSET,
    setup: Union[Unset, None, str] = UNSET,
    measurement_type: Union[Unset, None, str] = UNSET,
    keywords: Union[Unset, None, List[str]] = UNSET,
    variables_measured: Union[Unset, None, List[str]] = UNSET,
    offset: Union[Unset, None, int] = 0,
    ranking: Union[Unset, None, int] = 0,
    limit: Union[Unset, None, int] = 500,
) -> Optional[Union[BaseError, HTTPValidationError, List[DatasetOut]]]:
    """Get Datasets

    Args:
        scope (str):
        collection (Union[Unset, None, str]):
        name (Union[Unset, None, str]):
        uid (Union[Unset, None, str]):
        since (Union[Unset, None, datetime.datetime]):
        until (Union[Unset, None, datetime.datetime]):
        sample (Union[Unset, None, str]):
        fridge (Union[Unset, None, str]):
        setup (Union[Unset, None, str]):
        measurement_type (Union[Unset, None, str]):
        keywords (Union[Unset, None, List[str]]):
        variables_measured (Union[Unset, None, List[str]]):
        offset (Union[Unset, None, int]):
        ranking (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):  Default: 500.

    Returns:
        Response[Union[BaseError, HTTPValidationError, List[DatasetOut]]]
    """

    return sync_detailed(
        client=client,
        scope=scope,
        collection=collection,
        name=name,
        uid=uid,
        since=since,
        until=until,
        sample=sample,
        fridge=fridge,
        setup=setup,
        measurement_type=measurement_type,
        keywords=keywords,
        variables_measured=variables_measured,
        offset=offset,
        ranking=ranking,
        limit=limit,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    scope: str,
    collection: Union[Unset, None, str] = UNSET,
    name: Union[Unset, None, str] = UNSET,
    uid: Union[Unset, None, str] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    until: Union[Unset, None, datetime.datetime] = UNSET,
    sample: Union[Unset, None, str] = UNSET,
    fridge: Union[Unset, None, str] = UNSET,
    setup: Union[Unset, None, str] = UNSET,
    measurement_type: Union[Unset, None, str] = UNSET,
    keywords: Union[Unset, None, List[str]] = UNSET,
    variables_measured: Union[Unset, None, List[str]] = UNSET,
    offset: Union[Unset, None, int] = 0,
    ranking: Union[Unset, None, int] = 0,
    limit: Union[Unset, None, int] = 500,
) -> Response[Union[BaseError, HTTPValidationError, List[DatasetOut]]]:
    """Get Datasets

    Args:
        scope (str):
        collection (Union[Unset, None, str]):
        name (Union[Unset, None, str]):
        uid (Union[Unset, None, str]):
        since (Union[Unset, None, datetime.datetime]):
        until (Union[Unset, None, datetime.datetime]):
        sample (Union[Unset, None, str]):
        fridge (Union[Unset, None, str]):
        setup (Union[Unset, None, str]):
        measurement_type (Union[Unset, None, str]):
        keywords (Union[Unset, None, List[str]]):
        variables_measured (Union[Unset, None, List[str]]):
        offset (Union[Unset, None, int]):
        ranking (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):  Default: 500.

    Returns:
        Response[Union[BaseError, HTTPValidationError, List[DatasetOut]]]
    """

    kwargs = _get_kwargs(
        client=client,
        scope=scope,
        collection=collection,
        name=name,
        uid=uid,
        since=since,
        until=until,
        sample=sample,
        fridge=fridge,
        setup=setup,
        measurement_type=measurement_type,
        keywords=keywords,
        variables_measured=variables_measured,
        offset=offset,
        ranking=ranking,
        limit=limit,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    scope: str,
    collection: Union[Unset, None, str] = UNSET,
    name: Union[Unset, None, str] = UNSET,
    uid: Union[Unset, None, str] = UNSET,
    since: Union[Unset, None, datetime.datetime] = UNSET,
    until: Union[Unset, None, datetime.datetime] = UNSET,
    sample: Union[Unset, None, str] = UNSET,
    fridge: Union[Unset, None, str] = UNSET,
    setup: Union[Unset, None, str] = UNSET,
    measurement_type: Union[Unset, None, str] = UNSET,
    keywords: Union[Unset, None, List[str]] = UNSET,
    variables_measured: Union[Unset, None, List[str]] = UNSET,
    offset: Union[Unset, None, int] = 0,
    ranking: Union[Unset, None, int] = 0,
    limit: Union[Unset, None, int] = 500,
) -> Optional[Union[BaseError, HTTPValidationError, List[DatasetOut]]]:
    """Get Datasets

    Args:
        scope (str):
        collection (Union[Unset, None, str]):
        name (Union[Unset, None, str]):
        uid (Union[Unset, None, str]):
        since (Union[Unset, None, datetime.datetime]):
        until (Union[Unset, None, datetime.datetime]):
        sample (Union[Unset, None, str]):
        fridge (Union[Unset, None, str]):
        setup (Union[Unset, None, str]):
        measurement_type (Union[Unset, None, str]):
        keywords (Union[Unset, None, List[str]]):
        variables_measured (Union[Unset, None, List[str]]):
        offset (Union[Unset, None, int]):
        ranking (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):  Default: 500.

    Returns:
        Response[Union[BaseError, HTTPValidationError, List[DatasetOut]]]
    """

    return (
        await asyncio_detailed(
            client=client,
            scope=scope,
            collection=collection,
            name=name,
            uid=uid,
            since=since,
            until=until,
            sample=sample,
            fridge=fridge,
            setup=setup,
            measurement_type=measurement_type,
            keywords=keywords,
            variables_measured=variables_measured,
            offset=offset,
            ranking=ranking,
            limit=limit,
        )
    ).parsed



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..models.collection_dataset_out import CollectionDatasetOut
from ..models.dataset_out_meta import DatasetOutMeta
from ..models.file_dataset_out import FileDatasetOut
from ..types import UNSET, Unset

T = TypeVar("T", bound="DatasetOut")


@attr.s(auto_attribs=True)
class DatasetOut:
    """
    Attributes:
        name (str):
        uid (str):
        scope (str):
        collections (List[CollectionDatasetOut]):
        creator (Union[Unset, str]):
        description (Union[Unset, str]):
        meta (Union[Unset, DatasetOutMeta]):
        started (Union[Unset, datetime.datetime]):
        duration (Union[Unset, float]):
        ranking (Union[Unset, int]):
        created (Union[Unset, datetime.datetime]):
        modified (Union[Unset, datetime.datetime]):
        files (Union[Unset, List[FileDatasetOut]]):
    """

    name: str
    uid: str
    scope: str
    collections: List[CollectionDatasetOut]
    creator: Union[Unset, str] = UNSET
    description: Union[Unset, str] = UNSET
    meta: Union[Unset, DatasetOutMeta] = UNSET
    started: Union[Unset, datetime.datetime] = UNSET
    duration: Union[Unset, float] = UNSET
    ranking: Union[Unset, int] = 0
    created: Union[Unset, datetime.datetime] = UNSET
    modified: Union[Unset, datetime.datetime] = UNSET
    files: Union[Unset, List[FileDatasetOut]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        uid = self.uid
        scope = self.scope
        collections = []
        for collections_item_data in self.collections:
            collections_item = collections_item_data.to_dict()

            collections.append(collections_item)

        creator = self.creator
        description = self.description
        meta: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.meta, Unset):
            meta = self.meta

        started: Union[Unset, str] = UNSET
        if not isinstance(self.started, Unset):
            if self.started:
                started = self.started.isoformat()
            else:
                started = None

        duration = self.duration
        ranking = self.ranking
        created: Union[Unset, str] = UNSET
        if not isinstance(self.created, Unset):
            created = self.created.isoformat()

        modified: Union[Unset, str] = UNSET
        if not isinstance(self.modified, Unset):
            modified = self.modified.isoformat()

        files: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.files, Unset):
            files = []
            for files_item_data in self.files:
                files_item = files_item_data.to_dict()

                files.append(files_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "uid": uid,
                "scope": scope,
                "collections": collections,
            }
        )
        if creator is not UNSET:
            field_dict["creator"] = creator
        if description is not UNSET:
            field_dict["description"] = description
        if meta is not UNSET:
            field_dict["meta"] = meta
        if started is not UNSET:
            field_dict["started"] = started
        if duration is not UNSET:
            field_dict["duration"] = duration
        if ranking is not UNSET:
            field_dict["ranking"] = ranking
        if created is not UNSET:
            field_dict["created"] = created
        if modified is not UNSET:
            field_dict["modified"] = modified
        if files is not UNSET:
            field_dict["files"] = files

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        uid = d.pop("uid")

        scope = d.pop("scope")

        collections = []
        _collections = d.pop("collections")
        for collections_item_data in _collections:
            collections_item = CollectionDatasetOut.from_dict(collections_item_data)

            collections.append(collections_item)

        creator = d.pop("creator", UNSET)

        description = d.pop("description", UNSET)

        _meta = d.pop("meta", UNSET)
        meta: Union[Unset, DatasetOutMeta]
        if isinstance(_meta, Unset):
            meta = UNSET
        else:
            #meta = DatasetOutMeta.from_dict(_meta)
            meta = _meta

        _started = d.pop("started", UNSET)
        started: Union[Unset, datetime.datetime]
        if isinstance(_started, Unset):
            started = UNSET
        else:
            started = isoparse(_started) if _started else None

        duration = d.pop("duration", UNSET)

        ranking = d.pop("ranking", UNSET)

        _created = d.pop("created", UNSET)
        created: Union[Unset, datetime.datetime]
        if isinstance(_created, Unset):
            created = UNSET
        else:
            created = isoparse(_created)

        _modified = d.pop("modified", UNSET)
        modified: Union[Unset, datetime.datetime]
        if isinstance(_modified, Unset):
            modified = UNSET
        else:
            modified = isoparse(_modified)

        files = []
        _files = d.pop("files", UNSET)
        for files_item_data in _files or []:
            files_item = FileDatasetOut.from_dict(files_item_data)

            files.append(files_item)

        dataset_out = cls(
            name=name,
            uid=uid,
            scope=scope,
            collections=collections,
            creator=creator,
            description=description,
            meta=meta,
            started=started,
            duration=duration,
            ranking=ranking,
            created=created,
            modified=modified,
            files=files,
        )

        dataset_out.additional_properties = d
        return dataset_out

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['etiket_client',
 'etiket_client.api',
 'etiket_client.api.access',
 'etiket_client.api.collections',
 'etiket_client.api.datasets',
 'etiket_client.api.files',
 'etiket_client.api.metadata',
 'etiket_client.api.scope',
 'etiket_client.api.tus',
 'etiket_client.api.user',
 'etiket_client.models']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=21.3.0',
 'httpx>=0.15.4,<0.23.0',
 'python-dateutil>=2.8.0,<3.0.0',
 'shortuuid>=1.0.11,<2.0.0',
 'tuspy>=1.0.0,<2.0.0']

setup_kwargs = {
    'name': 'etiket-client',
    'version': '0.1.2',
    'description': 'A client library for accessing etiket',
    'long_description': '# etiket-client\n\nA client library for accessing etiket  $e|i>$ \n\n## Logging in to etiket\n\nFirst, create a client:\n\n```python\nfrom etiket_client import Client\n\nclient = Client(base_url="https://etiket.example.com") #of course change base_url\n```\n\nYou can only use the unauthenticated client to call the login endpoint with your credentials to obtain a valid token:\n\n```python\nfrom etiket_client import Client\nfrom etiket_client.api.access import login_for_access_token as get_token\nfrom etiket_client.models import BodyLoginForAccessToken\n\nclient = Client(base_url="https://etiket.example.com")\nform_data = BodyLoginForAccessToken(username=username, password=password)\n\ntoken = get_token.sync(client=client, form_data=form_data)\naccess_token = token.access_token\nrefresh_token = token.refresh_token\n```\n\nOther endpoints require authentication, use `AuthenticatedClient` with obtained access token as above:\n\n```python\nfrom etiket_client import AuthenticatedClient\n\nclient = AuthenticatedClient(\n                base_url="https://etiket.example.com", #of course change base_url\n                token="SuperSecretToken"\n)\n```\n\n## Creating datasets\n\nA minimal example of creating a dataset is shown below. Note that a scope should already be created and available to you. \n\n```python\nimport shortuuid\n\nfrom etiket_client.models import DatasetIn, DatasetOut\nfrom etiket_client.api.datasets import create_dataset\nfrom etiket_client.types import Response\n\n<...you have obtained tokens and created client: AuthenticatedClient...>\n\ndataset_new = DatasetIn(\n                    name=\'awesomedataset\',\n                    uid=shortuuid.ShortUUID().random(length=10),\n                    scope=\'somescope\',\n)\nresponse: DatasetOut = create_dataset.sync(\n                            client=client, \n                            json_body = dataset_new\n)\n# or if you need more info (e.g. status_code)\nresponse: Response[DatasetOut] = create_dataset.sync(\n                                    client=client,\n                                    json_body = dataset_new,\n)\n```\n\nWhen a dataset is created, it requires a unique identifer string, uid. Above we created a random string of length 10 which would be unique enough for a lifetime, but you can choose your own way to create a unique identifier. This also allows already created datasets with a different type of uid (e.g. UUID, TUID) to be added easily to $e|i>$.  A single dataset can then be uniquely identified through \'scope/uid\'. Although, a dataset is uniquely defined by the combination of a scope and uid, it is typically recognized by name, description, ranking and additional user defined metadata. \n\nAdditionally, a list of files can also be defined upon creation of the dataset. Note that the files will **not** be uploaded upon creation of datasets. Upload is done explicitly via `/uploads` endpoint or with `etiket_client.api.tus` methods.   \n\n```python\nfrom etiket_client.models import DatasetIn, DatasetOut\nfrom etiket_client.api.datasets import create_dataset\nfrom etiket_client.types import Response\n\nfile1 = FileDatasetIn(name=\'filename1\',uid=shortuuid.ShortUUID().random(length=10))\nfile2 = FileDatasetIn(name=\'filename2\',uid=shortuuid.ShortUUID().random(length=10))\ndataset_new = DatasetIn(\n                    name=\'awesomedataset\', \n                    scope=\'somescope\',\n\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0uid=shortuuid.ShortUUID().random(length=10),\n                    files=[file1,file2]\n)\ndataset: DatasetOut = create_dataset.sync(\n                            client=client,\n                            json_body = dataset_new\n)\n```\n\nFiles can of course also be added after dataset creation by calling `etiket_client.api.file.add_file`. \n\n## Collections and metadata\n\nDatasets can be grouped into collections. First a collection needs to be created, and subsequently datasets can be added to the collection:\n\n```python\nfrom etiket_client.models import CollectionIn\nfrom etiket_client.api.collections import create_collection, add_dataset_to_collection\n\ncollection  = create_collection.sync(\n                client=client,\n                json_body=CollectionIn(\n                                name=\'somecollection\',\n                                scope=\'somescope\',\n                          )            \n)\n\nresponse = add_dataset_to_collection.sync(\n                client=client,\n                scope=\'somescope\',\n                name=collection.name,\n                dataset_uuid=dataset.uuid,\n)\n```\n\nDatasets can also be removed from collections. \n\nAdditional user defined metadata can be provided to datasets in JSON format, either upon creation of the dataset by adding a meta field or explicitly via metadata functions:\n\n```python\ndataset_new = DatasetIn(\n                name=\'awesomedataset\',\n                scope=\'somescope\',\n\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0\xa0uid=shortuuid.ShortUUID().random(length=10),\n                files=[file1,file2],\n                meta={\'key1\':\'value1\', \'key2\':[\'value2a\',\'value2b\']},\n)\n```\n\nNote that the JSON document that can be added is limited in format. Only key-value pairs or key-list(values) pairs are allowed, where all keys and values are strings ( more than 2 and less than  20 characters). Arbitrary keys can be added, but not all keys can be used in dataset query. Only a predefined list of keys can be used when  querying datasets: sample, fridge, setup, measurement_type, variablesMeasured, keywords. \n\n## Exploring datasets\n\nA dataset is identified by a scope and UUID, but you can query or list datasets given a scope filtering on additional metadata to be able to browse through datasets:\n\n```python\nfrom etiket_client.api.datasets import get_datasets\n\ndatasets  = get_datasets.sync(\n                client=client,\n                scope=\'somescope\',\n                collection=\'somecollection\',\n                name=\'prefixofdataset\',\n                since=datetime.utcnow() - timedelta(days=100),\n                until=datetime.utcnow() + timedelta(days=1),\n                ranking=0,\n                sample=\'samplename\',\n                fridge=\'bluefors\',                \n)\n```\n\nDatasets are ordered by date of creation and use pagination to limit the number of datasets per request. Use offset and limit to move through pages.\n\nVia the ranking attribute of a dataset you can specify which datasets are filtered out of the query. Only datasets larger than the requested ranking will be returned. In this way, you can favour datasets over others. \n\n## Uploading files\n\nFile uploads are done using the tus.io protocol. `tuspy` package which is included in this client can be used: [tuspy docs](https://tus-py-client.readthedocs.io/en/latest/).\n\nAn etiket upload client can be initalized:\n\n```python\nfrom etiket_client import AuthenticatedClient, UploadClient\n\nclient = AuthenticatedClient(\n                base_url="https://etiket.example.com", #of course change base_url\n                token="SuperSecretToken"\n)\n\n#initialize tus client with autenticated client\ntus = UploadClient(client)\n#or optinally specify scope\ntus = UploadClient(client,scope=scope)\n\n#create uploader by specifying scope and file_uid\nuploader = tus.uploader(\'path/to/file\',scope=scope, file_uid=file_uid)\n\n#or only file_uid if scope is already specified in UploadClient\nuploader = tus.uploader(\'path/to/file\',file_uid=file_uid)\n\n#chunk size is sys.maxsize by default (probably quite large)\n#you can specify chunksize\nuploader = tus.uploader(\'path/to/file\', scope=scope, file_uid=file_uid, chunk_size=1024)\n\n#instead of path provide filestream\nfs = open(\'path/to/file.ext\', mode=)\nuploader = tus.uploader(file_stream=fs, scope=scope, file_uid=file_uid, chunk_size=200)\n\n# Upload a chunk i.e 200 bytes.\nuploader.upload_chunk()\n\n# Uploads the entire file.\n# This uploads chunk by chunk.\nuploader.upload()\n\n# you could increase the chunk size to reduce the\n# number of upload_chunk cycles.\nuploader.chunk_size = 800\nuploader.upload()\n\n# Continue uploading chunks till total chunks uploaded reaches 1000 bytes.\nuploader.upload(stop_at=1000)\n```\n\n\n## Downloading files\n\nFile downloads are done by using the ```get_file``` method. Optionally a range_ header can be added to do a partial download and perform downloads in parallel.\n',
    'author': 'None',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ScopeUpdate")


@attr.s(auto_attribs=True)
class ScopeUpdate:
    """
    Attributes:
        description (Union[Unset, str]):
        restricted (Union[Unset, bool]):
        archived (Union[Unset, bool]):
    """

    description: Union[Unset, str] = UNSET
    restricted: Union[Unset, bool] = UNSET
    archived: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        description = self.description
        restricted = self.restricted
        archived = self.archived

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if description is not UNSET:
            field_dict["description"] = description
        if restricted is not UNSET:
            field_dict["restricted"] = restricted
        if archived is not UNSET:
            field_dict["archived"] = archived

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        description = d.pop("description", UNSET)

        restricted = d.pop("restricted", UNSET)

        archived = d.pop("archived", UNSET)

        scope_update = cls(
            description=description,
            restricted=restricted,
            archived=archived,
        )

        scope_update.additional_properties = d
        return scope_update

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient
from ...models.base_error import BaseError
from ...models.collection_out import CollectionOut
from ...models.http_validation_error import HTTPValidationError
from ...types import Response


def _get_kwargs(
    scope: str,
    name: str,
    dataset_uid: str,
    *,
    client: AuthenticatedClient,
) -> Dict[str, Any]:
    url = "{}/api/v1/collections/{scope}/{name}/datasets/{dataset_uid}".format(
        client.base_url, scope=scope, name=name, dataset_uid=dataset_uid
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "put",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[Union[BaseError, CollectionOut, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = CollectionOut.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = BaseError.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = BaseError.from_dict(response.json())

        return response_401
    if response.status_code == 403:
        response_403 = BaseError.from_dict(response.json())

        return response_403
    if response.status_code == 404:
        response_404 = BaseError.from_dict(response.json())

        return response_404
    if response.status_code == 409:
        response_409 = BaseError.from_dict(response.json())

        return response_409
    if response.status_code == 410:
        response_410 = BaseError.from_dict(response.json())

        return response_410
    if response.status_code == 413:
        response_413 = BaseError.from_dict(response.json())

        return response_413
    if response.status_code == 500:
        response_500 = BaseError.from_dict(response.json())

        return response_500
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    return None


def _build_response(*, response: httpx.Response) -> Response[Union[BaseError, CollectionOut, HTTPValidationError]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    scope: str,
    name: str,
    dataset_uid: str,
    *,
    client: AuthenticatedClient,
) -> Response[Union[BaseError, CollectionOut, HTTPValidationError]]:
    """Add Dataset To Collection

    Args:
        scope (str):
        name (str):
        dataset_uid (str):

    Returns:
        Response[Union[BaseError, CollectionOut, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        scope=scope,
        name=name,
        dataset_uid=dataset_uid,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    scope: str,
    name: str,
    dataset_uid: str,
    *,
    client: AuthenticatedClient,
) -> Optional[Union[BaseError, CollectionOut, HTTPValidationError]]:
    """Add Dataset To Collection

    Args:
        scope (str):
        name (str):
        dataset_uid (str):

    Returns:
        Response[Union[BaseError, CollectionOut, HTTPValidationError]]
    """

    return sync_detailed(
        scope=scope,
        name=name,
        dataset_uid=dataset_uid,
        client=client,
    ).parsed


async def asyncio_detailed(
    scope: str,
    name: str,
    dataset_uid: str,
    *,
    client: AuthenticatedClient,
) -> Response[Union[BaseError, CollectionOut, HTTPValidationError]]:
    """Add Dataset To Collection

    Args:
        scope (str):
        name (str):
        dataset_uid (str):

    Returns:
        Response[Union[BaseError, CollectionOut, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        scope=scope,
        name=name,
        dataset_uid=dataset_uid,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    scope: str,
    name: str,
    dataset_uid: str,
    *,
    client: AuthenticatedClient,
) -> Optional[Union[BaseError, CollectionOut, HTTPValidationError]]:
    """Add Dataset To Collection

    Args:
        scope (str):
        name (str):
        dataset_uid (str):

    Returns:
        Response[Union[BaseError, CollectionOut, HTTPValidationError]]
    """

    return (
        await asyncio_detailed(
            scope=scope,
            name=name,
            dataset_uid=dataset_uid,
            client=client,
        )
    ).parsed



from enum import Enum


class FileType(str, Enum):
    SRC = "src"
    PREVIEW = "preview"
    RAW = "raw"
    DERIVED = "derived"
    CONF = "conf"

    def __str__(self) -> str:
        return str(self.value)
